require 'autoprefixer-rails'

module Reustyle
  class Engine < ::Rails::Engine
    add_paths_block = lambda { |app|
      Reustyle.asset_directories.each do |asset_directory|
        app.config.assets.paths << File.join(Reustyle.assets_path, asset_directory)
      end
    }

    initializer "reustyle.assets.precompile" do |app|
      app.config.assets.precompile += %w( icons/**.* icons.svg forms/*.svg)
    end

    initializer "reustyle.update_asset_paths", &add_paths_block
    initializer "reustyle.update_asset_paths", group: :assets, &add_paths_block
  end

  class Railtie < ::Rails::Railtie
    if config.respond_to?(:assets) and not config.assets.nil?
      config.assets.configure do |env|
        AutoprefixerRails.install(env, Reustyle.autoprefixer_config)
      end
    else
      initializer :setup_autoprefixer, group: :all do |app|
        if defined? app.assets and not app.assets.nil?
          AutoprefixerRails.install(app.assets, Reustyle.autoprefixer_config)
        end
      end
    end
  end
end
