lib_path = File.join(File.dirname(__FILE__), 'lib')
$:.unshift(lib_path) unless $:.include?(lib_path)

require 'reustyle'
require 'reustyle/deploy'
require 'fileutils'

namespace :reustyle do
  desc "Publishes uStyle v#{Reustyle::VERSION}"
  task :upgrade => [ "git:add", "git:push" ] do
    puts green("Committing new version of uStyle - v#{Reustyle::VERSION}")
  end

  task :publish => [ "deploy:images", "deploy:stylesheets" ] do
    puts green("Publishing uStyle v#{Reustyle::VERSION}")
  end
end

namespace :git do
  task :add do
    `git commit -am '#{Reustyle::VERSION}' && git tag -a v#{Reustyle::VERSION} -m '#{Reustyle::VERSION}'`
  end

  desc "Push version #{Reustyle::VERSION} to github"
  task :push do
    `git push -u -f && git push -f --tags`
  end
end

namespace :deploy do
  desc "Deploy stylesheets to S3"
  task :stylesheets do
    Dir["dist/*.{css,json,js,svg}"].each do |file|
      file_name = File.basename(file)
      content_type = Reustyle.mime_type_for(file_name)
      Reustyle.s3_upload( Reustyle.versioned_path(file_name), file, content_type )
      Reustyle.s3_upload( "reustyle/#{file_name}", file, content_type )
    end

    Reustyle.invalidate([
      "/s3/#{Reustyle::BUCKET}/reustyle/reustyle-latest.css",
      "/s3/#{Reustyle::BUCKET}/reustyle/rebrand-latest.css",
      "/s3/#{Reustyle::BUCKET}/reustyle/reustyle.min.js",
      "/s3/#{Reustyle::BUCKET}/reustyle/reustyle-content.css",
      "/s3/#{Reustyle::BUCKET}/reustyle/rebrand-content.css",
      "/s3/#{Reustyle::BUCKET}/reustyle/icons.svg"
    ])
  end

  desc "Deploy images to S3"
  task :images do
    images_dir = File.join Reustyle.assets_path, "images", "**", "*"
    Dir[images_dir].each do |file|
      next if File.directory?(file)
      file_path = file.gsub(Regexp.new("#{Reustyle.assets_path}/"), "")
      hashed_file = Reustyle.asset_digest(file_path)
      Reustyle.s3_upload( Reustyle.versioned_path(hashed_file), file, Reustyle.mime_type_for(file))
    end
  end
end

def colorize(text, color_code)
  "\e[#{color_code}m#{text}\e[0m"
end

def red(text); colorize(text, 31); end
def green(text); colorize(text, 32); end
